@@ -13,8 +13,9 @@
 #' @param reorient if \code{retimg=TRUE} pass to \code{\link{readNIfTI}}
 #' @param ... Arguments passed to \code{\link{run_spm12_script}}
 #' @export
-#' @return Result from run_matlab_script or nifti file, depending on 
-#' \code{retimg}
+#' @return List of output files (or niftis depending on \code{retimg}),
+#' output matrix, and output deformations.
+#' @importFrom neurobase nii.stub
 spm12_segment <- function(filename, 
                           retimg = TRUE,
                           set_origin = TRUE,
@@ -29,10 +30,10 @@ spm12_segment <- function(filename,
   # check filenames
   filename = filename_check(filename)  
   
-  if (set_origin){
+  if (set_origin) {
     res = acpc_reorient(infiles = filename, verbose = verbose)
     if (verbose) {
-      cat(paste0("# Result of acpc_reorient:", res, "\n"))
+      message(paste0("# Result of acpc_reorient:", res, "\n"))
     }
   }
   
@@ -48,13 +49,28 @@ spm12_segment <- function(filename,
                           clean = clean,
                           verbose = verbose,
                           ...)  
+  outfiles = file.path(
+    dirname(filename), 
+    paste0("c", 1:6, basename(filename)))
   
-  if (retimg){
-    outfiles = file.path(dirname(filename), 
-                         paste0("c", 1:6, basename(filename)))  
-    res = lapply(outfiles, readNIfTI, reorient = reorient)
-    return(res)
+  out_mat = file.path(dirname(filename),
+                      paste0(  
+                        nii.stub(filename, bn = TRUE),
+                        "_seg8.mat"))
+  
+  out_def = file.path(dirname(filename),
+                      paste0(
+                        "y_",
+                        basename(filename)))
+  res = list(
+    outfiles = outfiles,
+    outmat = out_mat,
+    deformation = out_def)
+  
+  if (retimg) {
+    res$outfiles = check_nifti(outfiles, reorient = reorient)
   }
+  
   return(res)
 }
 
